/*
 * Copyright (C) 2010 David Arkell.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.gwtorbit.client.widgets;

import com.google.gwt.event.dom.client.ChangeHandler;
import com.google.gwt.event.dom.client.HasChangeHandlers;
import com.google.gwt.event.dom.client.HasKeyPressHandlers;
import com.google.gwt.event.dom.client.HasKeyUpHandlers;
import com.google.gwt.event.dom.client.KeyPressHandler;
import com.google.gwt.event.dom.client.KeyUpHandler;
import com.google.gwt.event.shared.HandlerRegistration;
import com.gwtorbit.client.model.UiData;
import com.gwtorbit.client.model.UiDataDisplay;
import com.gwtorbit.client.model.UiErrors;

public class FormUiTextBoxInteger extends FormAbstractRowWithUiErrorDisplay implements
		UiDataDisplay, HasChangeHandlers, HasKeyPressHandlers, HasKeyUpHandlers {

	private UiTextBoxInteger field;

	public FormUiTextBoxInteger() {
		field = new UiTextBoxInteger();
		setFieldWidget(field);
	}

	public void setEnabled(boolean enabled) {
		field.setEnabled(enabled);
	}

	public boolean isEnabled() {
		return field.isEnabled();
	}

	public void setMandatory(boolean mandatory) {
		super.setMandatory(mandatory);
		field.setMandatory(mandatory);
	}

	public HandlerRegistration addChangeHandler(ChangeHandler handler) {
		return field.addChangeHandler(handler);
	}

	public HandlerRegistration addKeyPressHandler(KeyPressHandler handler) {
		return field.addKeyPressHandler(handler);
	}

	public HandlerRegistration addKeyUpHandler(KeyUpHandler handler) {
		return field.addKeyUpHandler(handler);
	}

	public void setFocus(boolean focused) {
		field.setFocus(focused);
	}

	public String getDataName() {
		return field.getDataName();
	}

	public void setDataName(String dataName) {
		super.setDataName(dataName);
		field.setDataName(dataName);
	}

	public void displayErrors(UiErrors errors, String errorPrefix) {
		super.displayErrors(errors, errorPrefix);
		field.displayErrors(errors, errorPrefix);
	}

	public void displayData(UiData uiData) {
		field.displayData(uiData);
	}

	public void getData(UiData uiData, UiErrors errors, String errorPrefix) {
		field.getData(uiData, errors, errorPrefix);
	}

	public void clearErrors() {
		super.clearErrors();
		field.clearErrors();
	}

	public void clearData() {
		field.clearData();
	}

	public boolean getIgnore() {
		return field.getIgnore();
	}

	public void setIgnore(boolean ignore) {
		field.setIgnore(ignore);
	}

	public void setFieldSize(String size) {
		field.setFieldSize(size);
	}

	public String getFieldSize() {
		return field.getFieldSize();
	}

	public void setFieldName(String name) {
		field.setName(name);
	}

	public String getFieldName() {
		return field.getName();
	}

}
