/*
 * Copyright (C) 2010 David Arkell.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.gwtorbit.client.widgets;

import com.google.gwt.user.client.ui.PasswordTextBox;
import com.gwtorbit.client.model.UiData;
import com.gwtorbit.client.model.UiDataDisplay;
import com.gwtorbit.client.model.UiErrorDisplay;
import com.gwtorbit.client.model.UiErrors;
import com.gwtorbit.client.model.UiLocalizedError;

public class UiPasswordTextBox extends PasswordTextBox implements UiDataDisplay, UiErrorDisplay {

	public UiPasswordTextBox() {
		setFieldSize("medium");
	}

	public void displayData(UiData uiData) {
		if (ignore) {
			return;
		}

		setText((String) uiData.getData(dataName));
	}

	public void getData(UiData uiData, UiErrors errors, String errorPrefix) {
		if (ignore) {
			return;
		}

		String text = this.getText();

		if (mandatory && "".equals(text)) {
			errors.addError(errorPrefix + dataName, UiLocalizedError.MANDATORY);
		}

		uiData.setData(dataName, text);
	}

	public void clearData() {
		if (ignore) {
			return;
		}

		setText("");
	}

	private boolean mandatory = false;

	private String dataName;

	public String getDataName() {
		return dataName;
	}

	public void setDataName(String dataName) {
		this.dataName = dataName;
	}

	public void setMandatory(boolean mandatory) {
		this.mandatory = mandatory;
	}

	public boolean isMandatory() {
		return mandatory;
	}

	public void clearErrors() {
		this.removeStyleName("UiTextBoxError");
	}

	public void displayErrors(UiErrors errors, String errorPrefix) {
		if (errors.hasErrors(errorPrefix + dataName)) {
			this.addStyleName("UiTextBoxError");
		}
	}

	private boolean ignore = false;

	public boolean getIgnore() {
		return ignore;
	}

	public void setIgnore(boolean ignore) {
		this.ignore = ignore;
	}

	private String fieldSize;

	public void setFieldSize(String size) {
		if ("short".equalsIgnoreCase(size)) {
			fieldSize = "short";
			setStyleName("UiTextBoxShort");
		} else if ("long".equalsIgnoreCase(size)) {
			fieldSize = "long";
			setStyleName("UiTextBoxLong");
		} else {
			fieldSize = "medium";
			setStyleName("UiTextBoxMedium");
		}
	}

	public String getFieldSize() {
		return fieldSize;
	}

}
