/*
 * Copyright (C) 2010 David Arkell.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.gwtorbit.client.widgets;

import java.util.Date;

import com.google.gwt.user.datepicker.client.DateBox;
import com.gwtorbit.client.model.UiData;
import com.gwtorbit.client.model.UiDataDisplay;
import com.gwtorbit.client.model.UiErrorDisplay;
import com.gwtorbit.client.model.UiErrors;
import com.gwtorbit.client.model.UiLocalizedError;
import com.gwtorbit.client.mvp.ClientResourceBundle;

public class UiTextBoxDateTime extends DateBox implements UiDataDisplay, UiErrorDisplay {

	public UiTextBoxDateTime() {
		setFormat(new DateBox.DefaultFormat(ClientResourceBundle.dateTimeFormat));
		setStyleName("UiTextBoxMedium");
	}

	public void displayData(UiData uiData) {
		if (ignore) {
			return;
		}

		setValue((Date) uiData.getData(dataName));
	}

	public void getData(UiData uiData, UiErrors errors, String errorPrefix) {
		if (ignore) {
			return;
		}

		Date date = getValue();
		String text = getTextBox().getText();

		if (mandatory && "".equals(text)) {
			errors.addError(errorPrefix + dataName, UiLocalizedError.MANDATORY);
		}

		if (!"".equals(text) && date == null) {
			errors.addError(errorPrefix + dataName, UiLocalizedError.INVALID);
		}

		uiData.setData(dataName, date);
	}

	public void clearData() {
		if (ignore) {
			return;
		}

		getTextBox().setText("");
	}

	private boolean mandatory = false;

	private String dataName;

	private boolean ignore = false;

	public String getDataName() {
		return dataName;
	}

	public void setDataName(String dataName) {
		this.dataName = dataName;
	}

	public void setMandatory(boolean mandatory) {
		this.mandatory = mandatory;
	}

	public boolean isMandatory() {
		return mandatory;
	}

	public void clearErrors() {
		removeStyleName("UiTextBoxError");
	}

	public void displayErrors(UiErrors errors, String errorPrefix) {
		if (errors.hasErrors(errorPrefix + dataName)) {
			addStyleName("UiTextBoxError");
		}
	}

	public boolean getIgnore() {
		return ignore;
	}

	public void setIgnore(boolean ignore) {
		this.ignore = ignore;
	}

	public boolean isEnabled() {
		return getTextBox().isEnabled();
	}

}
